@@ -79,6 +79,12 @@ pub struct MemberEventContent {
     #[serde(rename = "xyz.amorgan.blurhash")]
     #[serde(skip_serializing_if = "Option::is_none")]
     pub blurhash: Option<String>,
+
+    /// The reason for leaving a room.
+    #[cfg(feature = "unstable-pre-spec")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub reason: Option<String>,
 }
 
 impl MemberEventContent {
@@ -92,13 +98,19 @@ impl MemberEventContent {
             third_party_invite: None,
             #[cfg(feature = "unstable-pre-spec")]
             blurhash: None,
+            #[cfg(feature = "unstable-pre-spec")]
+            reason: None,
         }
     }
 }
 
 /// The membership state of a user.
+///
+/// This type can hold an arbitrary string. To check for formats that are not available as a
+/// documented variant here, use its string representation, obtained through `.as_str()`.
 #[derive(Clone, Debug, PartialEq, Eq, StringEnum)]
 #[ruma_enum(rename_all = "lowercase")]
+#[non_exhaustive]
 pub enum MembershipState {
     /// The user is banned.
     Ban,
@@ -119,6 +131,13 @@ pub enum MembershipState {
     _Custom(String),
 }
 
+impl MembershipState {
+    /// Creates a string slice from this `MembershipState`.
+    pub fn as_str(&self) -> &str {
+        self.as_ref()
+    }
+}
+
 /// Information about a third party invitation.
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
@@ -241,6 +260,8 @@ fn membership_change(
             third_party_invite: None,
             #[cfg(feature = "unstable-pre-spec")]
             blurhash: None,
+            #[cfg(feature = "unstable-pre-spec")]
+            reason: None,
         }
     };
 
