@@ -41,7 +41,7 @@ pub struct MessageEventContent {
     /// Information about related messages for [rich replies].
     ///
     /// [rich replies]: https://matrix.org/docs/spec/client_server/r0.6.1#rich-replies
-    #[serde(flatten, with = "relation_serde", skip_serializing_if = "Option::is_none")]
+    #[serde(flatten, skip_serializing_if = "Option::is_none")]
     pub relates_to: Option<Relation>,
 }
 
@@ -265,6 +265,7 @@ impl From<MessageType> for MessageEventContent {
 ///
 /// Currently used for replies and editing (message replacement).
 #[derive(Clone, Debug)]
+#[allow(clippy::manual_non_exhaustive)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub enum Relation {
     /// An `m.in_reply_to` relation indicating that the event is a reply to another event.
@@ -277,6 +278,9 @@ pub enum Relation {
     #[cfg(feature = "unstable-pre-spec")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
     Replacement(Replacement),
+
+    #[doc(hidden)]
+    _Custom,
 }
 
 /// Information about the event a "rich reply" is replying to.
